# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.endpoint import api_endpoint_pb2 as yandex_dot_cloud_dot_endpoint_dot_api__endpoint__pb2
from yandex.cloud.endpoint import api_endpoint_service_pb2 as yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2


class ApiEndpointServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.endpoint.ApiEndpointService/Get',
        request_serializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.GetApiEndpointRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__pb2.ApiEndpoint.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.endpoint.ApiEndpointService/List',
        request_serializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.ListApiEndpointsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.ListApiEndpointsResponse.FromString,
        )


class ApiEndpointServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ApiEndpointServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.GetApiEndpointRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__pb2.ApiEndpoint.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.ListApiEndpointsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_endpoint_dot_api__endpoint__service__pb2.ListApiEndpointsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.endpoint.ApiEndpointService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
